"""
Fake data for testing LibreLingo-related packages
"""

from librelingo_fakes.fakes import *

__version__ = '0.1.2'
